@@ -1,10 +1,7 @@
-from loguru import logger
+from firecore.logging import get_logger
 
+logger = get_logger(__name__)
 try:
     import torch
 except ImportError:
     logger.exception("please install pytorch first")
-
-
-from . import optimizer_utils
-from . import jit_utils
