@@ -1,14 +1,16 @@
 from pathlib import Path
 import functools
 import torch
-from loguru import logger
+from firecore.logging import get_logger
+
+logger = get_logger(__name__)
 
 
 class AutoExporter:
     def __init__(self, path: str) -> None:
         export_dir = Path(path)
 
-        logger.debug('make dirs: {}', export_dir)
+        logger.debug('make dirs', export_dir=export_dir)
         export_dir.mkdir(parents=True, exist_ok=True)
 
         self._export_dir = export_dir
@@ -27,7 +29,10 @@ class AutoExporter:
             if scripted_func is None:
                 scripted_func = torch.jit.trace(func, args)
                 output_path = self._export_dir / '{}.pt'.format(func_name)
-                logger.debug('save scripted funcion to {}', output_path)
+                logger.debug(
+                    'save scripted funcion',
+                    output_path=output_path
+                )
                 scripted_func.save(str(output_path))
 
             return scripted_func(*args)
